Widgets for the Jupyter notebook and JupyterLab
-----------------------------------------------

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

.. image:: https://travis-ci.org/astropy/astrowidgets.svg?branch=master
    :target: https://travis-ci.org/astropy/astrowidgets
    :alt: Travis CI Status

.. image:: https://readthedocs.org/projects/astrowidgets/badge/?version=latest
    :target: https://astrowidgets.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

``astrowidgets`` aims to be a set of astronomy widgets for Jupyter Lab or Notebook,
leveraging the Astropy ecosystem. The ``ImageWidget`` implements the API documented at
`https://github.com/eteq/nb-astroimage-api <https://github.com/eteq/nb-astroimage-api>`_

**Warning**

``astrowidgets`` is currently in *very* early development.  Nothing is guaranteed to work or do anything in particular
at this stage.


Installation and Documentation
------------------------------

See https://astrowidgets.readthedocs.io/en/latest/ .

License
-------

See ``LICENSE.rst``.


Contributing
------------

Given the pre-alpha nature of this package, there is no established
contributing guide. Please contact the maintainers for guidance.
It is important that you follow our code of conduct; please see
``CODE_OF_CONDUCT.md``.


Changelog
---------

See ``CHANGES.rst``.
